{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "pt",
  "clipboard.copy": "Copiar para área de transferência",
  "clipboard.copied": "Copiado para área de transferência",
  "edit.link.title": "Editar esta página",
  "footer.previous": "Anterior",
  "footer.next": "Próximo",
  "meta.comments": "Comentários",
  "meta.source": "Fonte",
  "search.config.lang": "pt",
  "search.placeholder": "Buscar",
  "search.result.placeholder": "Digite para iniciar a busca",
  "search.result.none": "Nenhum resultado encontrado",
  "search.result.one": "1 resultado encontrado",
  "search.result.other": "# resultados encontrados",
  "skip.link.title": "Ir para o conteúdo",
  "source.link.title": "Ir ao repositório",
  "source.revision.date": "Última atualização",
  "toc.title": "Índice"
}[key] }}{% endmacro %}
