{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "bn",
  "clipboard.copy": "ক্লিপবোর্ডে কপি করুন",
  "clipboard.copied": "ক্লিপবোর্ডে কপি হয়েছে",
  "edit.link.title": "এই পেজ এডিট করুন",
  "footer.previous": "পূর্ববর্তী",
  "footer.next": "পরে",
  "footer.title": "ফুটার",
  "header.title": "হেডার",
  "meta.comments": "কমেন্ট",
  "meta.source": "সোর্স",
  "nav.title": "ন্যাভিগেশন",
  "search.config.pipeline": " ",
  "search.placeholder": "সার্চ",
  "search.reset": "মুছে ফেলুন",
  "search.result.placeholder": "সার্চ টাইপ করুন",
  "search.result.none": "কিছু পাওয়া যায়নি",
  "search.result.one": "১ টা ডকুমেন্ট",
  "search.result.other": "# টা ডকুমেন্ট",
  "skip.link.title": "কনটেন্টে যান",
  "source.link.title": "রিপোজিটরিতে যান",
  "source.revision.date": "শেষ আপডেট",
  "tabs.title": "ট্যাব",
  "toc.title": "টেবিল অফ কনটেন্ট"
}[key] }}{% endmacro %}
