{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "af",
  "clipboard.copy": "Kopieer na knipbord",
  "clipboard.copied": "gekopieer na knipbord",
  "edit.link.title": "Wysig hierdie bladsy",
  "footer.previous": "Vorige",
  "footer.next": "Volgende",
  "meta.comments": "Kommentaar",
  "meta.source": "Bron",
  "search.config.lang": "nl",
  "search.placeholder": "Soek",
  "search.result.placeholder": "Tik om te begin soek",
  "search.result.none": "Geen ooreenstemmende dokumente",
  "search.result.one": "1 ooreenstemmende dokument",
  "search.result.other": "# ooreenstemmende dokumente",
  "skip.link.title": "Slaan oor na inhoud",
  "source.link.title": "Slaan oor na inhoud",
  "source.revision.date": "Laaste opdatering",
  "toc.title": "Inhoudsopgawe"
}[key] }}{% endmacro %}
