{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "kr",
  "clipboard.copy": "클립보드로 복사",
  "clipboard.copied": "클립보드에 복사됨",
  "edit.link.title": "이 페이지를 편집",
  "footer.previous": "이전",
  "footer.next": "다음",
  "meta.comments": "댓글",
  "meta.source": "출처",
  "search.config.pipeline": " ",
  "search.placeholder": "검색",
  "search.result.placeholder": "검색어를 입력하세요",
  "search.result.none": "검색어와 일치하는 문서가 없습니다",
  "search.result.one": "1개의 일치하는 문서",
  "search.result.other": "#개의 일치하는 문서",
  "source.link.title": "저장소로 이동",
  "source.revision.date": "마지막 업데이트",
  "toc.title": "목차"
}[key] }}{% endmacro %}
