{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "fi",
  "clipboard.copy": "Kopioi leikepöydälle",
  "clipboard.copied": "Kopioitu leikepöydälle",
  "edit.link.title": "Muokkaa tätä sivua",
  "footer.previous": "Edellinen",
  "footer.next": "Seuraava",
  "meta.comments": "Kommentit",
  "meta.source": "Lähdekodi",
  "search.config.lang": "fi",
  "search.placeholder": "Hae",
  "search.result.placeholder": "Kirjoita aloittaaksesi haun",
  "search.result.none": "Ei täsmääviä dokumentteja",
  "search.result.one": "1 täsmäävä dokumentti",
  "search.result.other": "# täsmäävää dokumenttia",
  "skip.link.title": "Hyppää sisältöön",
  "source.link.title": "Mene repositoryyn",
  "source.revision.date": "Viimeisin päivitys",
  "toc.title": "Sisällysluettelo"
}[key] }}{% endmacro %}
