{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "gl",
  "clipboard.copy": "Copiar no cortapapeis",
  "clipboard.copied": "Copiado no cortapapeis",
  "edit.link.title": "Editar esta páxina",
  "footer.previous": "Anterior",
  "footer.next": "Seguinte",
  "meta.comments": "Comentarios",
  "meta.source": "Fonte",
  "search.config.lang": "es",
  "search.placeholder": "Busca",
  "search.result.placeholder": "Insira un termo",
  "search.result.none": "Sen resultados",
  "search.result.one": "1 resultado atopado",
  "search.result.other": "# resultados atopados",
  "skip.link.title": "Ir ao contido",
  "source.link.title": "Ir ao repositorio",
  "source.revision.date": "Última actualización",
  "toc.title": "Táboa de contidos"
}[key] }}{% endmacro %}
