{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "he",
  "direction": "rtl",
  "clipboard.copy": "העתק ללוח",
  "clipboard.copied": "הועתק ללוח",
  "edit.link.title": "ערוך דף זה",
  "footer.previous": "קודם",
  "footer.next": "הַבָּא",
  "meta.comments": "הערות",
  "meta.source": "מָקוֹר",
  "search.config.pipeline": " ",
  "search.placeholder": "לחפש",
  "search.result.placeholder": "הקלד כדי להתחיל לחפש",
  "search.result.none": "אין מסמכים תואמים",
  "search.result.one": "1 מסמך תואם",
  "search.result.other": "# מסמך תואם",
  "skip.link.title": "דלג לתוכן",
  "source.link.title": "עבור אל מאגר",
  "source.revision.date": "העדכון אחרון",
  "toc.title": "תוכן העניינים"
}[key] }}{% endmacro %}
