{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "th",
  "clipboard.copy": "คัดลอก",
  "clipboard.copied": "คัดลอกแล้ว",
  "edit.link.title": "แก้ไขหน้านี้",
  "footer.previous": "ก่อนหน้า",
  "footer.next": "ต่อไป",
  "meta.comments": "ความคิดเห็น",
  "meta.source": "แหล่งที่มา",
  "search.config.pipeline": " ",
  "search.placeholder": "ค้นหา",
  "search.result.placeholder": "พิมพ์เพื่อเริ่มค้นหา",
  "search.result.none": "ไม่พบเอกสารที่ตรงกัน",
  "search.result.one": "พบเอกสารที่ตรงกัน",
  "search.result.other": "พบ # เอกสารที่ตรงกัน",
  "skip.link.title": "ข้ามไปที่เนื้อหา",
  "source.link.title": "ไปที่ Repository",
  "toc.title": "สารบัญ"
}[key] }}{% endmacro %}
