{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "eo",
  "clipboard.copy": "Kopii al tondujo",
  "clipboard.copied": "Kopiado al klipo",
  "edit.link.title": "Redakti ĉi tiun paĝon",
  "footer.previous": "Antaŭa",
  "footer.next": "Sekva",
  "footer.title": "Piedlinio",
  "header.title": "Kaplinio",
  "meta.comments": "Komentoj",
  "meta.source": "Fontkodo",
  "nav.title": "Navigado",
  "search.config.lang": "es",
  "search.placeholder": "Serĉo",
  "search.reset": "Klara",
  "search.result.placeholder": "Tajpu por komenci serĉadon",
  "search.result.none": "Neniuj kongruaj dokumentoj",
  "search.result.one": "1 kongrua dokumento",
  "search.result.other": "# kongruaj dokumentoj",
  "skip.link.title": "Saltu al enhavo",
  "source.link.title": "Iru al deponejo",
  "source.revision.date": "Lasta ĝisdatigo",
  "tabs.title": "Langetoj",
  "toc.title": "Enhavtabelo"
}[key] }}{% endmacro %}
