{#-
  This file was automatically generated - do not edit
-#}
<nav class="product-switcher">
  <div class="menu-item-wrapper menu-item-wrapper--dropdown">
    <a class="menu-item menu-item--with-icon">
      {% if config.product == "proxy" %}
      <img src="{{ 'assets/images/logo-traefik-proxy-logo.svg' | url }}" height="48px" width="auto" alt="Traefik Proxy">
      {% elif config.product == "pilot" %}
      <img src="{{ 'assets/images/logo-traefik-pilot-logo.svg' | url }}" height="48px" width="auto" alt="Traefik Pilot">
      {% elif config.product == "enterprise" %}
      <img src="{{ 'assets/images/logo-traefik-enterprise-logo.svg' | url }}" height="48px" width="auto" alt="Traefik Enterprise">
      {% elif config.product == "mesh" %}
      <img src="{{ 'assets/images/logo-traefik-mesh-logo.svg' | url }}" height="48px" width="auto" alt="Traefik Mesh">
      {% endif %}
      <span class="icon">
        <svg width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-chevron-down">
          <polyline points="6 9 12 15 18 9"></polyline>
        </svg>
      </span>
    </a>
    <div class="nav-dropdown-menu nav-dropdown-menu--products">
      <div class="nav-dropdown-menu-wrapper">
        <div class="dm-header">Product Documentation</div>
        <div class="dm-items">
          {% if config.product != "proxy" %}
          <div class="dm-item">
            <div class="dmi-image proxy">
              <img src="{{ 'assets/images/traefik-proxy-logo.svg' | url }}" alt="Traefik Proxy Documentation">
            </div>
            <a class="dmi-details" href="https://doc.traefik.io/traefik/">
              <div class="dmi-title">Traefik Proxy</div>
              <div class="dmi-description">
                Expose, Secure and Monitor your modern applications
              </div>
            </a>
          </div>
          {% endif %} {% if config.product != "mesh" %}
          <div class="dm-item">
            <div class="dmi-image mesh">
              <img src="{{ 'assets/images/traefik-mesh-logo.svg' | url }}" alt="Traefik Mesh Documentation">
            </div>
            <a class="dmi-details" href="https://doc.traefik.io/traefik-mesh/">
              <div class="dmi-title">Traefik Mesh</div>
              <div class="dmi-description">
                Route and Monitor communications inside your Kubernetes cluster
              </div>
            </a>
          </div>
          {% endif %} {% if config.product != "enterprise" %}
          <div class="dm-item dm-item--traefikee">
            <div class="dmi-image enterprise">
              <img src="{{ 'assets/images/traefik-enterprise-logo.svg' | url }}" alt="Traefik Enterprise Documentation">
            </div>
            <a class="dmi-details" href="https://doc.traefik.io/traefik-enterprise/">
              <div class="dmi-title">Traefik Enterprise</div>
              <div class="dmi-description">
                Ensure high availability, scalability, and security of your
                microservices
              </div>
            </a>
          </div>
          {% endif %} {% if config.product != "pilot" %}
          <div class="dm-item dm-item--pilot">
            <div class="dmi-image pilot">
              <img src="{{ 'assets/images/traefik-pilot-logo.svg' | url }}" alt="Traefik Pilot Documentation">
            </div>
            <a class="dmi-details" href="https://doc.traefik.io/traefik-pilot/">
              <div class="dmi-title">Traefik Pilot</div>
              <div class="dmi-description">
                Monitor and Manage your Traefik Instances
              </div>
            </a>
          </div>
          {% endif %}
        </div>
      </div>
    </div>
  </div>
</nav>
