{#-
  This file was automatically generated - do not edit
-#}
{% macro t(key) %}{{ {
  "language": "ca",
  "clipboard.copy": "Còpia al porta-retalls",
  "clipboard.copied": "Copiat al porta-retalls",
  "edit.link.title": "Edita aquesta pàgina",
  "footer.previous": "Anterior",
  "footer.next": "Següent",
  "meta.comments": "Comentaris",
  "meta.source": "Codi font",
  "search.placeholder": "Cerca",
  "search.result.placeholder": "Escriu per a començar a cercar",
  "search.result.none": "Cap document coincideix",
  "search.result.one": "1 document coincident",
  "search.result.other": "# documents coincidents",
  "skip.link.title": "Salta el contingut",
  "source.link.title": "Ves al repositori",
  "source.revision.date": "Darrera actualització",
  "toc.title": "Taula de continguts"
}[key] }}{% endmacro %}
